The *cd-public.ps1* Script
===========================

This PowerShell script sets the current working directory to the Public folder.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/cd-public.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./cd-public.ps1
📂C:\Users\Public with 2 files and 3 folders entered.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Sets the working dir to the Public folder
.DESCRIPTION
	This PowerShell script sets the current working directory to the Public folder.
.EXAMPLE
	PS> ./cd-public.ps1
	📂C:\Users\Public with 2 files and 3 folders entered.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	if ($IsLinux) {
		if (-not(Test-Path "~/Public" -pathType container)) {
			throw "No 'Public' folder in your home directory yet"
		}
		$path = Resolve-Path "~/Public"
	} else {
		if (-not(Test-Path "~/../Public" -pathType container)) {
			throw "No 'Public' folder yet"
		}
		$path = Resolve-Path "~/../Public"
	}
	Set-Location "$path"
	$files = Get-ChildItem $path -attributes !Directory
	$folders = Get-ChildItem $path -attributes Directory
	"📂$path with $($files.Count) files and $($folders.Count) folders entered."
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:34)*
