The *cd-users.ps1* Script
===========================

This PowerShell script sets the current working directory to the users directory.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/cd-users.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./cd-users.ps1
📂C:\Users with 4 folders entered.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Sets the working dir to the users directory
.DESCRIPTION
	This PowerShell script sets the current working directory to the users directory.
.EXAMPLE
	PS> ./cd-users.ps1
	📂C:\Users with 4 folders entered.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$path = Resolve-Path "~/.."
	if (-not(Test-Path "$path" -pathType container)) {
		throw "No users directory at: $path"
	}
	Set-Location "$path"
	$folders = Get-ChildItem $path -attributes Directory
	"📂$path with $($folders.Count) folders entered."
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:34)*
