The *check-xml-file.ps1* Script
===========================

This PowerShell script checks the given XML file for validity.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/check-xml-file.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the path to the XML file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./check-xml-file.ps1 myfile.xml
✅ myfile.xml is valid XML

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Verifies an XML file
.DESCRIPTION
	This PowerShell script checks the given XML file for validity.
.PARAMETER path
	Specifies the path to the XML file
.EXAMPLE
	PS> ./check-xml-file.ps1 myfile.xml
	✅ myfile.xml is valid XML
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "")

try {
	if ($path -eq "" ) { $path = Read-Host "Enter path to XML file" }

	$XmlFile = Get-Item $path
	
	# Perform the XSD Validation
	$script:ErrorCount = 0
	$ReaderSettings = New-Object -TypeName System.Xml.XmlReaderSettings
	$ReaderSettings.ValidationType = [System.Xml.ValidationType]::Schema
	$ReaderSettings.ValidationFlags = [System.Xml.Schema.XmlSchemaValidationFlags]::ProcessInlineSchema -bor [System.Xml.Schema.XmlSchemaValidationFlags]::ProcessSchemaLocation
	$ReaderSettings.add_ValidationEventHandler({ $script:ErrorCount++ })
	$ReaderSettings.DtdProcessing = [System.Xml.DtdProcessing]::Parse
	$Reader = [System.Xml.XmlReader]::Create($XmlFile.FullName, $ReaderSettings)
	while ($Reader.Read()) { }
	$Reader.Close()
	
	if ($script:ErrorCount -gt 0) {	throw "Invalid XML" } 

	"✅ $path is valid XML"
	exit 0 # success
} catch {
	"⚠️ $($Error[0]) in 📄$path"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:35)*
