The *download-dir.ps1* Script
===========================

This PowerShell script downloads a folder (including subfolders) from the given URL.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/download-dir.ps1 [[-URL] <String>] [<CommonParameters>]

-URL <String>
    Specifies the URL where to download from
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./download-dir.ps1 https://www.cnn.com

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Downloads a folder (including subfolders) from an URL
.DESCRIPTION
	This PowerShell script downloads a folder (including subfolders) from the given URL.
.PARAMETER URL
	Specifies the URL where to download from
.EXAMPLE
	PS> ./download-dir.ps1 https://www.cnn.com
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$URL = "")

try {
	if ($URL -eq "") { $URL = Read-Host "Enter directory URL to download" }

	$StopWatch = [system.diagnostics.stopwatch]::startNew()

	& wget --version
	if ($lastExitCode -ne 0) { throw "Can't execute 'wget' - make sure wget is installed and available" }

	& wget --mirror --convert-links --adjust-extension --page-requisites --no-parent $URL --directory-prefix . --no-verbose
	if ($lastExitCode -ne 0) { throw "Can't execute 'wget --mirror $URL'" }

	[int]$Elapsed = $StopWatch.Elapsed.TotalSeconds
	"✅ downloaded directory from $URL in $Elapsed sec"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:36)*
