The *export-to-manuals.ps1* Script
===========================

This PowerShell script exports the comment-based help of all PowerShell scripts as manuals.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/export-to-manuals.ps1 [[-filePattern] <String>] [[-targetDir] <String>] [<CommonParameters>]

-filePattern <String>
    
    Required?                    false
    Position?                    1
    Default value                "$PSScriptRoot/*.ps1"
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

-targetDir <String>
    
    Required?                    false
    Position?                    2
    Default value                "$PSScriptRoot/../docs"
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./export-to-manuals.ps1
⏳ (1/2) Reading PowerShell scripts from /home/mf/PowerShell/scripts/*.ps1 ... 
⏳ (2/2) Exporting Markdown manuals to /home/mf/PowerShell/docs ...
✅ Exported 518 Markdown manuals in 28 sec.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Exports all scripts as manuals
.DESCRIPTION
	This PowerShell script exports the comment-based help of all PowerShell scripts as manuals.
.EXAMPLE
	PS> ./export-to-manuals.ps1
	⏳ (1/2) Reading PowerShell scripts from /home/mf/PowerShell/scripts/*.ps1 ... 
	⏳ (2/2) Exporting Markdown manuals to /home/mf/PowerShell/docs ...
	✅ Exported 518 Markdown manuals in 28 sec.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

#requires -version 2

param([string]$filePattern = "$PSScriptRoot/*.ps1", [string]$targetDir = "$PSScriptRoot/../docs")

try {
	$stopWatch = [system.diagnostics.stopwatch]::startNew()

	"⏳ (1/2) Reading PowerShell scripts from $filePattern ..." 
	$scripts = Get-ChildItem "$filePattern"

	"⏳ (2/2) Exporting Markdown manuals to $targetDir ..."
	foreach ($script in $scripts) {
		& "$PSScriptRoot/convert-ps2md.ps1" "$script" > "$targetDir/$($script.BaseName).md"
	}

	[int]$elapsed = $stopWatch.Elapsed.TotalSeconds
	"✅ Exported $($scripts.Count) Markdown manuals in $elapsed sec."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:36)*
