The *get-md5.ps1* Script
===========================

This PowerShell script calculates and prints the MD5 checksum of the given file.
NOTE: MD5 is no longer considered secure, use it for simple change validation only!

Parameters
----------
```powershell
/Repos/PowerShell/scripts/get-md5.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the file path to the file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./get-md5.ps1 C:\MyFile.txt
✅ MD5 hash is 041E16F16E60AD250EB794AF0681BD4A

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Prints the MD5 checksum of a file
.DESCRIPTION
	This PowerShell script calculates and prints the MD5 checksum of the given file.
	NOTE: MD5 is no longer considered secure, use it for simple change validation only!
.PARAMETER path
	Specifies the file path to the file
.EXAMPLE
	PS> ./get-md5.ps1 C:\MyFile.txt
	✅ MD5 hash is 041E16F16E60AD250EB794AF0681BD4A
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "")

try {
	if ($path -eq "" ) { $path = Read-Host "Enter the file path" }
	if (-not(Test-Path $path -pathType leaf)) { throw "Invalid file path given: $path" }

	$result = Get-FileHash -path $path -algorithm MD5

	"✅ MD5 hash is $($result.Hash)"
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:36)*
