The *get-sha1.ps1* Script
===========================

This PowerShell script calculates and prints the SHA1 checksum of the given file.
NOTE: SHA1 is no longer considered secure, use it for simple change validation only!

Parameters
----------
```powershell
/Repos/PowerShell/scripts/get-sha1.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the local file path to the file
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./get-sha1.ps1 C:\MyFile.txt
✅ SHA1 hash is 8105D424D350E308AED92BD9DDEB74A1B53C5D7C

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Prints the SHA1 hash of a file
.DESCRIPTION
	This PowerShell script calculates and prints the SHA1 checksum of the given file.
	NOTE: SHA1 is no longer considered secure, use it for simple change validation only!
.PARAMETER path
	Specifies the local file path to the file
.EXAMPLE
	PS> ./get-sha1.ps1 C:\MyFile.txt
	✅ SHA1 hash is 8105D424D350E308AED92BD9DDEB74A1B53C5D7C
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "")

try {
	if ($path -eq "" ) { $path = Read-Host "Enter the file path" }
	if (-not(Test-Path $path -pathType leaf)) { throw "Invalid file path given: $path" }

	$result = Get-FileHash -path $path -algorithm SHA1

	"✅ SHA1 hash is $($result.Hash)"
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:36)*
