The *remind-me.ps1* Script
===========================

This PowerShell script creates a scheduled task that will display a popup message.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/remind-me.ps1 [[-Message] <String>] [[-Time] <DateTime>] [<CommonParameters>]

-Message <String>
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

-Time <DateTime>
    
    Required?                    false
    Position?                    2
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./remind-me "Dentist" "4/10/2021 12:00 PM"



TaskPath                                       TaskName                          State
--------                                       --------                          -----
\                                              Reminder_451733811                Ready

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Creates a scheduled task that will display a popup message
.DESCRIPTION
	This PowerShell script creates a scheduled task that will display a popup message.
.EXAMPLE
	PS> ./remind-me "Dentist" "4/10/2021 12:00 PM"

	TaskPath                                       TaskName                          State
	--------                                       --------                          -----
	\                                              Reminder_451733811                Ready
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

#requires -version 4

param([string]$Message = "", [datetime]$Time)

try {
	if ($Message -eq "") { $Message = read-host "Enter reminder message" }

	$Task = New-ScheduledTaskAction -Execute msg -Argument "* $Message"
	$Trigger = New-ScheduledTaskTrigger -Once -At $Time
	$Random = (Get-Random)
	Register-ScheduledTask -Action $Task -Trigger $Trigger -TaskName "Reminder_$Random" -Description "Reminder"
	exit 0
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:40)*
