The *speak-croatian.ps1* Script
===========================

This PowerShell script speaks the given text with a Croatian text-to-speech (TTS) voice.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/speak-croatian.ps1 [[-text] <String>] [<CommonParameters>]

-text <String>
    Specifies the Croatian text to speak
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./speak-croatian.ps1 zdravo

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Speaks text in Croatian
.DESCRIPTION
	This PowerShell script speaks the given text with a Croatian text-to-speech (TTS) voice.
.PARAMETER text
	Specifies the Croatian text to speak
.EXAMPLE
	PS> ./speak-croatian.ps1 zdravo
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "")

try {
	if ($text -eq "") { $text = Read-Host "Enter the Croatian text to speak" }

	$TTS = New-Object -ComObject SAPI.SPVoice
	foreach ($voice in $TTS.GetVoices()) {
		if ($voice.GetDescription() -like "*- Croatian*") {
			$TTS.Voice = $voice
			[void]$TTS.Speak($text)
			exit 0 # success
		}
	}
	throw "No Croatian text-to-speech voice found - please install one."
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:41)*
