The *update-powershell-profile.ps1* Script
===========================

This PowerShell script write/overwrites the PowerShell profile of the current user.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/update-powershell-profile.ps1 [[-path] <String>] [<CommonParameters>]

-path <String>
    Specifies the path to the new profile ($PSScriptRoot/my-profile.ps1 by default)
    
    Required?                    false
    Position?                    1
    Default value                "$PSScriptRoot/my-profile.ps1"
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./update-powershell-profile.ps1
⏳ (1/2) Querying path to PowerShell profile 'CurrentUserCurrentHost'...
⏳ (2/2) Copying my-profile.ps1 to /home/Markus/.config/powershell/Microsoft.PowerShell_profile.ps1...
✅ Updated your PowerShell profile, it get's active on next login.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Updates the user's PowerShell profile
.DESCRIPTION
	This PowerShell script write/overwrites the PowerShell profile of the current user.
.PARAMETER path
	Specifies the path to the new profile ($PSScriptRoot/my-profile.ps1 by default)
.EXAMPLE
	PS> ./update-powershell-profile.ps1
	⏳ (1/2) Querying path to PowerShell profile 'CurrentUserCurrentHost'...
	⏳ (2/2) Copying my-profile.ps1 to /home/Markus/.config/powershell/Microsoft.PowerShell_profile.ps1...
	✅ Updated your PowerShell profile, it get's active on next login.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$path = "$PSScriptRoot/my-profile.ps1")

try {
	"⏳ (1/2) Querying path to PowerShell profile 'CurrentUserCurrentHost'..."
	$pathToProfile = $PROFILE.CurrentUserCurrentHost

	$filename = (Get-Item "$path").Name
	"⏳ (2/2) Copying $filename to $pathToProfile..."
	$null = New-Item -Path $pathToProfile -ItemType "file" -Force
	Copy-Item "$path" "$pathToProfile" -force

	"✅ Updated your PowerShell profile, it get's active on next login."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:41)*
