The *what-is.ps1* Script
===========================

This PowerShell script queries the meaning of the given term/abbreviation/etc. and prints it.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/what-is.ps1 [[-term] <String>] [<CommonParameters>]

-term <String>
    Specifies the term to query
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./what-is VTOL
💡 VTOL in aviation refers to: Vertical Take-Off and Landing

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Explains a term/abbreviation/etc.
.DESCRIPTION
	This PowerShell script queries the meaning of the given term/abbreviation/etc. and prints it.
.PARAMETER term
	Specifies the term to query
.EXAMPLE
	PS> ./what-is VTOL
	💡 VTOL in aviation refers to: Vertical Take-Off and Landing
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$term = "")

try {
	if ($term -eq "" ) { $term = Read-Host "Enter the term to query" }

	$files = Get-ChildItem "$PSScriptRoot/../data/dicts/*.csv"
	$basename = ""
	foreach($file in $files) {
		$table = Import-CSV "$file"
		foreach($row in $table) {
			if ($row.TERM -ne $term) { continue }
			$basename = (Get-Item "$file").Basename -Replace "_"," "
			"💡 $($row.TERM) in $basename refers to: $($row.MEANING)"
		}
	}
	if ($basename -eq "") {
		Write-Host "🤷‍ Sorry, '$term' is new to me. Let's search it at: " -noNewline
		Write-Host "https://www.qwant.com/?q=what+is+$term" -foregroundColor blue
	}
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:42)*
