The *write-centered.ps1* Script
===========================

This PowerShell script writes the given text centered to the console.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/write-centered.ps1 [[-text] <String>] [<CommonParameters>]

-text <String>
    Specifies the text to write
    
    Required?                    false
    Position?                    1
    Default value                
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./write-headline.ps1 "Hello World"
						Hello World

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Writes text centered
.DESCRIPTION
	This PowerShell script writes the given text centered to the console.
.PARAMETER text
	Specifies the text to write
.EXAMPLE
	PS> ./write-headline.ps1 "Hello World"
							Hello World
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "")

try {
	if ($text -eq "") { $text = Read-Host "Enter the text to write" }

	$ui = (Get-Host).ui
	$rui = $ui.rawui 
	[int]$numSpaces = ($rui.MaxWindowSize.Width - $text.Length) / 2

	[string]$spaces = ""
	for ([int]$i = 0; $i -lt $numSpaces; $i++) { $spaces += " " }
	Write-Host "$spaces$text"
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:42)*
