The *write-location.ps1* Script
===========================

This PowerShell script determines the location and writes it to the console.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/write-location.ps1 [<CommonParameters>]

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./write-location.ps1
📍47.7278°,10.3192° near 87435 Kempten in Bavaria, Germany.

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Writes the current location 
.DESCRIPTION
	This PowerShell script determines the location and writes it to the console.
.EXAMPLE
	PS> ./write-location.ps1
	📍47.7278°,10.3192° near 87435 Kempten in Bavaria, Germany.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	$location = (Invoke-WebRequest -URI http://ifconfig.co/json  -userAgent "curl" -useBasicParsing).Content | ConvertFrom-Json
	$lat = $location.latitude
	$long = $location.longitude
	$city = $location.city
	$zip = $location.zip_code
	$region = $location.region_name
	$country = $location.country
	Write-Output "📍$lat°,$long° near $zip $city in $region, $country."
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:42)*
