The *write-typewriter.ps1* Script
===========================

This PowerShell script writes the given text with the typewriter effect.

Parameters
----------
```powershell
/Repos/PowerShell/scripts/write-typewriter.ps1 [[-text] <String>] [[-speed] <Int32>] [<CommonParameters>]

-text <String>
    Specifies the text to write (sample text by default)
    
    Required?                    false
    Position?                    1
    Default value                Hello World, this is the PowerShell typewriter.
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

-speed <Int32>
    Specifies the speed (200 ms by default)
    
    Required?                    false
    Position?                    2
    Default value                200
    Accept pipeline input?       false
    Aliases                      
    Accept wildcard characters?  false

[<CommonParameters>]
    This script supports the common parameters: Verbose, Debug, ErrorAction, ErrorVariable, WarningAction, 
    WarningVariable, OutBuffer, PipelineVariable, and OutVariable.
```

Example
-------
```powershell
PS> ./write-typewriter.ps1 "Hello World"

```

Notes
-----
Author: Markus Fleschutz | License: CC0

Related Links
-------------
https://github.com/fleschutz/PowerShell

Script Content
--------------
```powershell
<#
.SYNOPSIS
	Writes text like a typewriter
.DESCRIPTION
	This PowerShell script writes the given text with the typewriter effect.
.PARAMETER text
	Specifies the text to write (sample text by default)
.PARAMETER speed
	Specifies the speed (200 ms by default)
.EXAMPLE
	PS> ./write-typewriter.ps1 "Hello World"
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

param([string]$text = "Hello World, this is the PowerShell typewriter.", [int]$speed = 200) # in milliseconds

try {
	$Random = New-Object System.Random
	$text -split '' | ForEach-Object {
		Write-Host $_ -noNewline
		Start-Sleep -milliseconds $Random.Next($speed)
	}
	Write-Host ""
	exit 0 # success
} catch {
	"⚠️ Error in line $($_.InvocationInfo.ScriptLineNumber): $($Error[0])"
	exit 1
}
```

*(page generated by convert-ps2md.ps1 as of 06/22/2025 10:37:42)*
