﻿<#
.SYNOPSIS
	Sets the working directory to the user's music folder
.DESCRIPTION
	This PowerShell script changes the working directory to the user's music folder.
.EXAMPLE
	PS> ./cd-music.ps1
	📂C:\Users\Markus\Music with 3 folders and 0 files entered.
.LINK
	https://github.com/fleschutz/PowerShell
.NOTES
	Author: Markus Fleschutz | License: CC0
#>

try {
	if ($IsLinux) {
		if (-not(Test-Path "~/Music/" -pathType container)) {
			throw "No 'Music' folder in home directory"
		}
		$path = Resolve-Path "~/Music"
	} else {
		$path = [Environment]::GetFolderPath('MyMusic')
		if (-not(Test-Path "$path" -pathType container)) {
			throw "No music folder at: $path"
		}
	}
	Set-Location "$path"
	$folders = Get-ChildItem $path -attributes Directory
	$files = Get-ChildItem $path -attributes !Directory
	"📂$path with $($folders.Count) folders and $($files.Count) files entered."
	exit 0 # success
} catch {
	"⚠️ Error: $($Error[0])"
	exit 1
}
